@@ -1,4 +1,4 @@
-package Email::Sender::Transport::SQLite 1.500;
+package Email::Sender::Transport::SQLite 1.501;
 # ABSTRACT: deliver mail to an sqlite db for testing
 
 use Moo;
@@ -181,7 +181,7 @@ Email::Sender::Transport::SQLite - deliver mail to an sqlite db for testing
 
 =head1 VERSION
 
-version 1.500
+version 1.501
 
 =head1 DESCRIPTION
 
@@ -212,10 +212,10 @@ recipient to the F<recipients> table.
 
 Delivery to this transport should never fail.
 
-=head1 PERL VERSION SUPPORT
+=head1 PERL VERSION
 
-This module has a long-term perl support period.  That means it will not
-require a version of perl released fewer than five years ago.
+This library should run on perls released even a long time ago.  It should work
+on any version of perl released in the last five years.
 
 Although it may work on older versions of perl, no guarantee is made that the
 minimum required version will not be increased.  The version may be increased
@@ -241,11 +241,17 @@ More fields may be added in the future.
 
 =head1 AUTHOR
 
+Ricardo Signes <cpan@semiotic.systems>
+
+=head1 CONTRIBUTOR
+
+=for stopwords Ricardo Signes
+
 Ricardo Signes <rjbs@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021 by Ricardo Signes.
+This software is copyright (c) 2022 by Ricardo Signes.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
